duodata
===

.. testsetup::

    from duodata.vo.examenkandidaten import examenkandidaten_vo

.. automodule:: duodata.vo.examenkandidaten
    :members:

.. automodule:: duodata.mbo.gediplomeerden
    :members:

.. automodule:: duodata.hbo.toestroom
    :members:
